{% load aa_theme_slate %}
{% load sri %}

{% sri_static "aa_theme_slate/theme/bootstrap5/libs/popper/v2.11.8/popper.min.js" %}
{% sri_static "aa_theme_slate/theme/bootstrap5/libs/bootswatch/v5.3.3/slate/javascript/bootstrap.min.js" %}
